pitchtools.chromatic_pitch_class_name_to_diatonic_pitch_class_name
==================================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_class_name_to_diatonic_pitch_class_name.chromatic_pitch_class_name_to_diatonic_pitch_class_name
